@@ -1,4 +1,5 @@
-/* Copyright (c) 2002, Juergen Schilling <juergen.schilling@honeywell.com>
+/* Copyright (c) 2002, 2003, 2004
+   Juergen Schilling <juergen.schilling@honeywell.com>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -23,10 +24,12 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom169.h,v 1.13 2003/06/13 20:43:08 arcanum Exp $ */
+/* $Id: iom169.h,v 1.13.2.3 2004/10/18 16:42:53 arcanum Exp $ */
 
 /* iom169.h - definitions for ATmega169 */
 
+/* This should be up to date with data sheet version 2514J-AVR-12/03. */
+
 #ifndef _AVR_IOM169_H_
 #define _AVR_IOM169_H_ 1
 
@@ -230,14 +233,20 @@
 #define ICR1H  _SFR_MEM8(0x87)
 
 /* Timer/Counter1 Output Compare Register A */
-#define OCRA1  _SFR_MEM16(0x88)
-#define OCRA1L _SFR_MEM8(0x88)
-#define OCRA1H _SFR_MEM8(0x89)
+#define OCR1A  _SFR_MEM16(0x88)
+#define OCRA1  OCR1A            /* For compatibility with previous releases. */
+#define OCR1AL _SFR_MEM8(0x88)
+#define OCRA1L OCR1AL           /* For compatibility with previous releases. */
+#define OCR1AH _SFR_MEM8(0x89)
+#define OCRA1H OCR1AH           /* For compatibility with previous releases. */
 
 /* Timer/Counter1 Output Compare Registare B */
-#define OCRB1  _SFR_MEM16(0x8A)
-#define OCRB1L _SFR_MEM8(0x8A)
-#define OCRB1H _SFR_MEM8(0x8B)
+#define OCR1B  _SFR_MEM16(0x8A)
+#define OCRB1  OCR1B            /* For compatibility with previous releases. */
+#define OCR1BL _SFR_MEM8(0x8A)
+#define OCRB1L OCR1BL           /* For compatibility with previous releases. */
+#define OCR1BH _SFR_MEM8(0x8B)
+#define OCRB1H OCR1BH           /* For compatibility with previous releases. */
 
 /* Timer/Counter2 Control Register A */
 #define TCCR2A _SFR_MEM8(0xB0)
@@ -261,21 +270,30 @@
 #define USIDR  _SFR_MEM8(0xBA)
 
 /* USART0 Control and Status Register A */
-#define UCSR0A _SFR_MEM8(0xC0)
+#define UCSRA  _SFR_MEM8(0xC0)
+#define UCSR0A UCSRA            /* For compatibility with previous releases. */
 
 /* USART0 Control and Status Register B */
-#define UCSR0B _SFR_MEM8(0xC1)
+#define UCSRB  _SFR_MEM8(0xC1)
+#define UCSR0B UCSRB            /* For compatibility with previous releases. */
 
 /* USART0 Control and Status Register C */
-#define UCSR0C _SFR_MEM8(0xC2)
+#define UCSRC  _SFR_MEM8(0xC2)
+#define UCSR0C UCSRC            /* For compatibility with previous releases. */
 
 /* USART0 Baud Rate Register */
-#define UBRR0  _SFR_MEM16(0xC4)
-#define UBRR0L _SFR_MEM8(0xC4)
-#define UBRR0H _SFR_MEM8(0xC5)
+#define UBRR   _SFR_MEM16(0xC4)
+#define UBRRL  _SFR_MEM8(0xC4)
+#define UBRRH  _SFR_MEM8(0xC5)
+
+/* For compatibility with previous releases. */
+#define UBRR0  UBRR
+#define UBRR0L UBRRL
+#define UBRR0H UBRRH
 
 /* USART0 I/O Data Register */
-#define UDR0   _SFR_MEM8(0xC6)
+#define UDR    _SFR_MEM8(0xC6)
+#define UDR0   UDR             /* For compatibility with previous releases. */
 
 /* LCD Control and Status Register A */
 #define LCDCRA _SFR_MEM8(0xE4)
@@ -321,9 +339,9 @@
 #define SIG_OUTPUT_COMPARE0     _VECTOR(10)
 #define SIG_OVERFLOW0           _VECTOR(11)
 #define SIG_SPI                 _VECTOR(12)
-#define SIG_UART0_RECV          _VECTOR(13)
-#define SIG_UART0_DATA          _VECTOR(14)
-#define SIG_UART0_TRANS         _VECTOR(15)
+#define SIG_USART_RECV          _VECTOR(13)
+#define SIG_USART_DATA          _VECTOR(14)
+#define SIG_USART_TRANS         _VECTOR(15)
 #define SIG_USI_START           _VECTOR(16)
 #define SIG_USI_OVERFLOW        _VECTOR(17)
 #define SIG_COMPERATOR          _VECTOR(18)
@@ -334,6 +352,12 @@
 
 #define _VECTORS_SIZE 92
 
+/* These are to avoid breaking code compiled against old names. */
+
+#define SIG_UART0_RECV          SIG_USART_RECV 
+#define SIG_UART0_DATA          SIG_USART_DATA
+#define SIG_UART0_TRANS         SIG_USART_TRANS
+
 /* Bit numbers */
 
 /*
@@ -592,7 +616,6 @@
  */
 
 /* PORTG */
-#define PG5 5
 #define PG4 4
 #define PG3 3
 #define PG2 2
@@ -724,7 +747,8 @@
 #define SPMEN  0
 
 /* WDTCR */
-#define WDTCE	4
+#define WDCE	4
+#define WDTCE	WDCE           /* For compatibility with previous releases. */
 #define WDE	   3
 #define WDP2	2
 #define WDP1	1
@@ -737,6 +761,10 @@
 #define CLKPS1 1
 #define CLKPS0 0
 
+/* EICRA */
+#define ISC01  1
+#define ISC00  0
+
 /* PCMSK0 */
 #define PCINT7 7
 #define PCINT6 6
@@ -782,7 +810,6 @@
 #define ADPS0  0
 
 /* ADCSRB */
-#define ADHSM  7
 #define ACME   6
 #define ADTS2  2
 #define ADTS1  1
@@ -798,11 +825,11 @@
 #define MUX1   1
 #define MUX0   0
 
-/* DIDR0 */
+/* DIDR1 */
 #define AIN1D  1
 #define AIN0D  0
 
-/* DIDR1 */
+/* DIDR0 */
 #define ADC7D  7
 #define ADC6D  6
 #define ADC5D  5
@@ -870,34 +897,63 @@
 #define USICNT1 1
 #define USICNT0 0
 
-/* UCSR0A */
-#define RXC0	7
-#define TXC0	6
-#define UDRE0	5
-#define FE0	   4
-#define DOR0	3
-#define UPE0 	2
-#define U2X0   1
-#define MPCM0	0
+/* UCSRA */
+#define RXC     7
+#define TXC     6
+#define UDRE    5
+#define FE      4
+#define DOR     3
+#define UPE     2
+#define U2X     1
+#define MPCM    0
 
-/* UCSR0B */
-#define RXCIE0	7
-#define TXCIE0	6
-#define UDRIE0	5
-#define RXEN0	4
-#define TXEN0	3
-#define UCSZ02 2
-#define RXB80	1
-#define TXB80	0
+/* UCSR0A -- For compatibility with previous releases. */
+#define RXC0    RXC
+#define TXC0    TXC
+#define UDRE0   UDRE
+#define FE0     FE
+#define DOR0    DOR
+#define UPE0    UPE
+#define U2X0    U2X
+#define MPCM0   MPCM
 
-/* UCSR0C */
-#define UMSEL0 6
-#define UPM01  5
-#define UPM00  4
-#define USBS0  3
-#define UCSZ01 2
-#define UCSZ00 1
-#define UCPOL0 0
+/* UCSRB */
+#define RXCIE   7
+#define TXCIE   6
+#define UDRIE   5
+#define RXEN    4
+#define TXEN    3
+#define UCSZ2   2
+#define RXB8    1
+#define TXB8    0
+
+/* UCSR0B -- For compatibility with previous releases. */
+#define RXCIE0  RXCIE
+#define TXCIE0  TXCIE
+#define UDRIE0  UDRIE
+#define RXEN0   RXEN
+#define TXEN0   TXEN
+#define UCSZ02  UCSZ2
+#define RXB80   RXB8
+#define TXB80   TXB8
+
+/* UCSRC */
+#define UMSEL   6
+#define UPM1    5
+#define UPM0    4
+#define USBS    3
+#define UCSZ1   2
+#define UCSZ0   1
+#define UCPOL   0
+
+/* UCSR0C -- For compatibility with previous releases. */
+#define UMSEL0  UMSEL
+#define UPM01   UPM1
+#define UPM00   UPM0
+#define USBS0   USBS
+#define UCSZ01  UCSZ1
+#define UCSZ00  UCSZ0
+#define UCPOL0  UCPOL
 
 /* LCDCRA */
 #define LCDEN  7
