@@ -23,7 +23,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom64.h,v 1.6.2.1 2003/10/20 18:58:30 troth Exp $ */
+/* $Id: iom64.h,v 1.6.2.2 2004/10/21 22:06:52 arcanum Exp $ */
 
 /* avr/iom64.h - defines for ATmega64 
 
@@ -827,7 +827,8 @@
 /* ADC Control and status Register A - ADCSRA */
 #define    ADEN         7
 #define    ADSC         6
-#define    ADFR         5
+#define    ADATE        5
+#define    ADFR         5 /* Defined for compatibility with previous releases */
 #define    ADIF         4
 #define    ADIE         3
 #define    ADPS2        2
