@@ -27,7 +27,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdio.h,v 1.11.2.3 2003/11/24 18:09:28 troth Exp $
+  $Id: stdio.h,v 1.11.2.4 2004/07/22 11:10:38 joerg_wunsch Exp $
 */
 
 #ifndef _STDIO_H_
@@ -93,6 +93,12 @@
     the linefeed, its \c put() routine must implement this (see
     \ref stdio_note2 "note 2").
 
+    It should be noted that the automatic conversion of a newline
+    character into a carriage return - newline sequence breaks binary
+    transfers.  If binary transfers are desired, no automatic
+    conversion should be performed, but instead any string that aims
+    to issue a CR-LF sequence must use <tt>"\r\n"</tt> explicitly.
+
     For convenience, the first call to \c fdevopen() that opens a
     stream for reading will cause the resulting stream to be aliased
     to \c stdin.  Likewise, the first call to \c fdevopen() that opens
